pub async fn probe_host(host: &str, port: u16, timeout_ms: u64) -> ProbeResultExpand description
Probe a host:port to detect the protocol by reading the server banner.
pub async fn probe_host(host: &str, port: u16, timeout_ms: u64) -> ProbeResultProbe a host:port to detect the protocol by reading the server banner.